@@ -1,6 +1,6 @@
 import numpy as np
 from scipy.sparse import issparse
-from sed_common import sll_opts,init_factor
+from sed.sed_common import sll_opts,init_factor
 
 def least_r(A: np.ndarray,y,z,opts):
     """
